"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setContext = exports.getContext = void 0;
const lodash_1 = require("lodash");
const path = require("path");
const fs = require("fs");
const getContext = () => {
    if (fs.existsSync(getContextFile())) {
        return JSON.parse(fs.readFileSync(getContextFile(), 'utf8'));
    }
    return {};
};
exports.getContext = getContext;
const setContext = (fn) => {
    const context = (0, exports.getContext)();
    const newContext = fn((0, lodash_1.cloneDeep)(context));
    fs.writeFileSync(getContextFile(), JSON.stringify(newContext));
};
exports.setContext = setContext;
const getContextFile = () => {
    // check if parent process has a context file
    if (fs.existsSync(getContextFileForPid(process.ppid))) {
        return getContextFileForPid(process.ppid);
    }
    // otherwise return our own
    return getContextFileForPid(process.pid);
};
const getContextFileForPid = (pid) => path.join('/tmp', `openapicmd-ctx-${pid}.json`);
