"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getRedocIndexHTML = exports.serveRedoc = void 0;
const URL = require("url");
const Koa = require("koa");
const Router = require("koa-router");
const common_tags_1 = require("common-tags");
const CURRENT_REDOC_VERSION = '2.1.2';
function serveRedoc(opts = {}) {
    const app = new Koa();
    const router = new Router();
    const indexHTML = getRedocIndexHTML(opts);
    // serve index.html
    router.get('/', (ctx) => {
        const url = ctx.originalUrl || ctx.url;
        const { pathname, query, hash } = URL.parse(url);
        // append trailing slash so relative paths work
        if (!pathname.endsWith('/')) {
            ctx.status = 302;
            return ctx.redirect(URL.format({
                pathname: `${pathname}/`,
                query,
                hash,
            }));
        }
        ctx.body = indexHTML;
        ctx.status = 200;
    });
    app.use(router.routes());
    return app;
}
exports.serveRedoc = serveRedoc;
function getRedocIndexHTML(opts = {}) {
    return (0, common_tags_1.html) `<html>
  <head>
    <title>${opts.title || 'ReDoc documentation'}</title>
    <meta charset="utf-8"/>
    <meta name="viewport" content="width=device-width, initial-scale=1">

    <!--
    Redoc doesn't change outer page styles
    -->
    <style>
      body {
        margin: 0;
        padding: 0;
      }
    </style>
  </head>
  <body>
    <redoc spec-url='${opts.specUrl || 'http://petstore.swagger.io/v2/swagger.json'}'></redoc>
    <script src="https://cdn.redoc.ly/redoc/v${opts.redocVersion || CURRENT_REDOC_VERSION}/bundles/redoc.standalone.js"></script>
  </body>
</html>`;
}
exports.getRedocIndexHTML = getRedocIndexHTML;
